Simple Earn Endpoints
=====================

Get Simple Earn Flexible Product List (USER_DATA)
-------------------------------------------------
.. autofunction:: binance.spot.Spot.get_simple_earn_flexible_product_list

Get Simple Earn Locked Product List (USER_DATA)
-----------------------------------------------
.. autofunction:: binance.spot.Spot.get_simple_earn_locked_product_list

Subscribe Flexible Product (TRADE)
----------------------------------
.. autofunction:: binance.spot.Spot.subscribe_flexible_product

Subscribe Locked Product (TRADE)
--------------------------------
.. autofunction:: binance.spot.Spot.subscribe_locked_product

Redeem Flexible Product (TRADE)
-------------------------------
.. autofunction:: binance.spot.Spot.redeem_flexible_product

Redeem Locked Product (TRADE)
-----------------------------
.. autofunction:: binance.spot.Spot.redeem_locked_product

Get Flexible Product Position (USER_DATA)
-----------------------------------------
.. autofunction:: binance.spot.Spot.get_flexible_product_position

Get Locked Product Position (USER_DATA)
---------------------------------------
.. autofunction:: binance.spot.Spot.get_locked_product_position

Simple Account (USER_DATA)
--------------------------
.. autofunction:: binance.spot.Spot.simple_account

Get Flexible Subscription Record (USER_DATA)
--------------------------------------------
.. autofunction:: binance.spot.Spot.get_flexible_subscription_record

Get Locked Subscription Record (USER_DATA)
------------------------------------------
.. autofunction:: binance.spot.Spot.get_locked_subscription_record

Get Flexible Redemption Record (USER_DATA)
------------------------------------------
.. autofunction:: binance.spot.Spot.get_flexible_redemption_record

Get Locked Redemption Record (USER_DATA)
----------------------------------------
.. autofunction:: binance.spot.Spot.get_locked_redemption_record

Get Flexible Rewards History (USER_DATA)
----------------------------------------
.. autofunction:: binance.spot.Spot.get_flexible_rewards_history

Get Locked Rewards History (USER_DATA)
--------------------------------------
.. autofunction:: binance.spot.Spot.get_locked_rewards_history

Set Flexible Auto Subscribe (USER_DATA)
---------------------------------------
.. autofunction:: binance.spot.Spot.set_flexible_auto_subscribe

Set Locked Auto Subscribe (USER_DATA)
-------------------------------------
.. autofunction:: binance.spot.Spot.set_locked_auto_subscribe

Get Flexible Personal Left Quota (USER_DATA)
--------------------------------------------
.. autofunction:: binance.spot.Spot.get_flexible_personal_left_quota

Get Locked Personal Left Quota (USER_DATA)
------------------------------------------
.. autofunction:: binance.spot.Spot.get_locked_personal_left_quota

Get Flexible Subscription Preview (USER_DATA)
---------------------------------------------
.. autofunction:: binance.spot.Spot.get_flexible_subscription_preview

Get Locked Subscription Preview (USER_DATA)
-------------------------------------------
.. autofunction:: binance.spot.Spot.get_locked_subscription_preview

Set Locked Product Redeem Option (USER_DATA)
--------------------------------------------
.. autofunction:: binance.spot.Spot.set_locked_product_redeem_option

Get Rate History (USER_DATA)
----------------------------
.. autofunction:: binance.spot.Spot.get_rate_history

Get Collateral Record (USER_DATA)
---------------------------------
.. autofunction:: binance.spot.Spot.get_collateral_record
